@@ -4,5 +4,5 @@ use strict;
 use CGI::Widget ":standard";
 
 
-print ref HList__Node();
-#print Series(-length=>10,-render=>sub{return "asdf".shift});
+#print ref HList__Node();
+print Series(-length=>10,-render=>sub{return "asdf".shift});
